# Import functions from chooser.py

from .chooser import chooser
from .chooser import sortchooser
from .chooser import revchooser

# Import functions from tests.py

from .tests import testnumbers
from .tests import testalphabet_lower
from .tests import testalphabet_upper
from .tests import testascii

__version__ = '1.1.1'


# The chooser.
import random as ra

def chooser(num: int, only: bool=False, *names):
    '''Quickly select num elements from the names.
    Optional - only: Does not repeat the element, 
    but reduces the number of elements returned.'''
    results = []
    for n in range(num):
        result = ra.choice(names)
        results.append(result)
    if only == True:
        return list(set(results))
    return results

def sortchooser(num: int, only: bool=False, *names):
    '''It's the same operation as chooser(), but sorted a bit.'''
    results = []
    for n in range(num):
        result = ra.choice(names)
        results.append(result)
    if only == True:
        return sorted(list(set(results)))
    return sorted(results)

def revchooser(num: int, only: bool=False, *names):
    '''Reverse order.'''
    results = []
    for n in range(num):
        result = ra.choice(names)
        results.append(result)
    if only == True:
        return reversed(list(set(results)))
    return reversed(results)


# It's just a test here, nothing.

from .chooser import chooser

def testnumbers(number: int=10, num: int=1, only: bool=False):
    '''Num numbers are randomly selected from the number.'''
    numbers = [n for n in range(number+1)]
    return chooser(num, only, *numbers)

def testalphabet_upper(num: int=1, only: bool=False):
    '''Num letters are randomly selected from 26 uppercase letters.'''
    letters = [chr(l) for l in range(65, 91)]
    return chooser(num, only, *letters)

def testalphabet_lower(num: int=1, only: bool=False):
    '''Num letters are randomly selected from 26 lowercase letters.'''
    letters = [chr(l) for l in range(97, 123)]
    return chooser(num, only, *letters)

def testascii(num: int=1, only: bool=False, low: int=32, up: int=127):
    '''Select from the ASCII code table.
    Optional - low/up : Sets the selected range.'''
    names = [chr(n) for n in range(low, up)]
    return chooser(num, only, *names)